//  файл дефайнов карты памяти
//      RTC  DS1307
//     ds1307_map.h

#ifndef ds1307_map_H   // Блокируем повторное включение этого модуля
#define ds1307_map_H   // включая заключительный #endif в конце файла
//------------------------------------------------------------------
// обязательная "магическая добавка" (начало)
#if ARDUINO >= 100
 #include "Arduino.h"
#else
 #include "WProgram.h"
#endif
// обязательная "магическая добавка" (конец)
//------------------------------------------------------------------

// карта памяти DS1307
#define adr_rtc_sec 0x00 // адрес регистра секунд
#define adr_rtc_min 0x01 // адрес регистра минут
#define adr_rtc_hours 0x02 // адрес регистра часов
#define adr_rtc_day 0x03 // адрес регистра дня недели
#define adr_rtc_date 0x04 // адрес регистра даты (число)
#define adr_rtc_mons 0x05 // адрес регистра месяца
#define adr_rtc_year 0x06 // адрес регистра года
#define adr_rtc_control 0x07 // адрес регистра контроля и управления
#define adr_start_ram 0x08 // адрес начала ОЗУ
#define adr_stop_ram 0x3F // адрес конца ОЗУ
#define rtc_ram_size 0x38 // объём ОЗУ = 56 байт

// контрольные биты RTC
#define adr_CH_bit 7 // адрес позиции бита запуска/останова счета
      // размещен в rtc_sec, ch_bit=0 - счет, ch_bit=1 останов
#define adr_OUT_bit 7 // адрес бита пассивного состояния выхода SQW_OUT
      // размещен в rtc_control, при SQWE_bit=0 и OUT_bit=0 SQW_OUT=0
      // при SQWE_bit=0 и OUT_bit=1 SQW/OUT=1
#define adr_SQWE_bit 4 // адрес позиции бита разрешения/запрета выдачи внешнего
     // тактового сигнала на вывод SQW_OUT размещен в rtc_control
     // SQWE_bit=0 на SQW_OUT пассивный статус (согласно OUT_bit)
     // SQWE_bit=1 на SQW_OUT частота согласно RS1_bit:RS0_bit
#define adr_RS1_bit 1 //
#define adr_RS0_bit 0 // адреса позиции битов выбора частоты
    // размещены в rtc_control
    //  RS1_bit:RS0_bit = 0:0 -> 1Hz (1S)
    //  RS1_bit:RS0_bit = 0:1 -> 4KHz (0,00025S)
    //  RS1_bit:RS0_bit = 1:0 -> 8KHz (0,000125S)
    //  RS1_bit:RS0_bit = 1:1 -> 32768Hz (0,00030517S)
#define adr_apm_bit 6 // адрес позиции бита режима представления часов
    // размещен в rtc_hours
   // apm_bit=0 -> 24 часовой фромат
   // apm_bit=1 -> 12 часовой фромат, статус бита 5 определяет
   // rtc_hours.5=0 -> АМ , rtc_hours.5=1 -> РМ

// командные байты DS1307
#define Nw_ds1307 0b11010000 // 0b11010000 имя устройства для записи
#define Nr_ds1307 0b11010001 // 0b11010001 имя устройства для чтения

// адресное поле ОЗУ RTC
#define tmp_r0 8
#define tmp_r1 9
#define tmp_r2 0xA
#define tmp_r3 0xB
#define tmp_r4 0xC
#define tmp_r5 0xD
#define tmp_r6 0xE
#define tmp_r7 0xF
#define tmp_r8 0x10
#define tmp_r9 0x11
#define tmp_r10 0x12
#define tmp_r11 0x13
#define tmp_r12 0x14
#define tmp_r13 0x15
#define tmp_r14 0x16
#define tmp_r15 0x17
#define tmp_r16 0x18
#define tmp_r17 0x19
#define tmp_r18 0x1A
#define tmp_r19 0x1B
#define tmp_r20 0x1C
#define tmp_r21 0x1D
#define tmp_r22 0x1E
#define tmp_r23 0x1F
#define tmp_r24 0x20
#define tmp_r25 0x21
#define tmp_r26 0x22
#define tmp_r27 0x23
#define tmp_r28 0x24
#define tmp_r29 0x25
#define tmp_r30 0x26
#define tmp_r31 0x27
#define tmp_r32 0x28
#define tmp_r33 0x29
#define tmp_r34 0x2A
#define tmp_r35 0x2B
#define tmp_r36 0x2C
#define tmp_r37 0x2D
#define tmp_r38 0x2E
#define tmp_r39 0x2F
#define tmp_r40 0x30
#define tmp_r41 0x31
#define tmp_r42 0x32
#define tmp_r43 0x33
#define tmp_r44 0x34
#define tmp_r45 0x35
#define tmp_r46 0x36
#define tmp_r47 0x37
#define tmp_r48 0x38
#define tmp_r49 0x39
#define tmp_r50 0x3A
#define tmp_r51 0x3B
#define tmp_r52 0x3C
#define tmp_r53 0x3D
#define tmp_r54 0x3E
#define tmp_r55 0x3F

#endif
//-------------конец файла/end of file---------------------
