/* ---------------------------------------------------- */
/*       заголовочный файл общих функций
       (дисплей,главные часы, клавиатура)
                 genkey.h                              */
//-------------------------------------------------------
#ifndef _GENKEY_H        // Блокируем повторное включение этого модуля
#define _GENKEY_H
//------------------------------------------------------------------------
// обязательная "магическая добавка" (начало)
#if ARDUINO >= 100
 #include "Arduino.h"
#else
 #include "WProgram.h"
#endif
// обязательная "магическая добавка" (конец)
//------------------------------------------------------------------------
#include "skans.h" // файл физического сканера клавиатуры
#include "max72m.h" // заголовочный *.h файл комплекта библиотеки max72m
#include "mxiicr.h" // заголовочный *.h файл комплекта библиотеки mxiicm
                   // (только физический протокол пересылки байта)
#include "ds1307_map.h" // карта ресурсов DS1307
#include "myclock.h" // файл функций устройства "главные часы"
#include "secmetr.h" // подключение файла обработчика секундомера

//------------------------------------------------------------------------
//    линии управления внешними исполнительными устройствами

// индикатор работы исполнительного устройства
// в качесиве индикатора используется "мигающий/переливающийся"
// светодиод с 5 вольтовым питанием
//активный уровень равен 1
#define Led_Out 8

//------------------------------------------------------------------------
//           начальная настройка дисплея
/* 
 *  настройка индикатора "по умолчанию"
 *  сканирование всех 8 позиций
 *  режим знакосинтеза
 *  яркость~60%
 *  исходно позиции заполнены "пробелами"
 */
extern void disp_init();

//------------------------------------------------------------------------
//                главные часы
//        (обеспечение отсчета и индикации)

// байт флагов главных часов
extern volatile byte G_ClkF;
// флаг разрешения счета для счетчиков
#define En_Clock 0
// флаг разрешения вывода значений
// главных часов на индикацию
#define En_ClkInd 1
// флаг запроса обработки вывода на индикацию
// очередного изменения содержимого счетчиков секунд,
// минут и часов главных часов
#define Qt_ClkInd 2

#define Qt_work 3
// флаг разрешения обработки данных
// очередного приращения счетчиков минут и часов главных часов
// для будильника A
#define En_budA 4
// флаг разрешения обработки данных
    // очередного приращения счетчиков минут и часов главных часов
    // для будильника B
#define En_budB 5

extern volatile byte GcntS; // счетчик секунд главных часов
extern volatile byte GcntM; // счетчик минут главных часов
extern volatile byte GcntH; // счетчик часов главных часов
#define mod60 60 // модуль счета секунд и минут
#define mod24 24 // модуль счета часов

// функция обработчика контроля и приращения
// счетчиков главных часов
extern void Gclock_work();

// раскладка для вывода на индикацию показаний главных часов
#define GclkIndSl addp0 // адрес регистра данных позиции S*1
#define GclkIndSh addp1 // адрес регистра данных позиции S*10
#define GclkInd_1 addp2 // адрес регистра данных позиции "-"
#define GclkIndMl addp3 // адрес регистра данных позиции M*1
#define GclkIndMh addp4 // адрес регистра данных позиции M*10
#define GclkInd_2 addp5 // адрес регистра данных позиции "-"
#define GclkIndHl addp6 // адрес регистра данных позиции H*1
#define GclkIndHh addp7 // адрес регистра данных позиции H*10

// основной модуль вывода на индикацию показаний главных часов
extern void Gclock_ind();

// декодер байт со значением двоичной тетрады (0х0N)
// в байт знакосинтеза max7219
extern byte Gclock_iZnak(byte);

//------------------------------------------------------------------------
//           обработчики общего функционала клавиатуры
//------------------------------------------------------------------------
#define Ex_trigF 0 // имя позиции триггер-флага кнопы Exec_key в trig_flags
#define Dn_trigF 1 // имя позиции триггер-флага кнопы Down_key в trig_flags
#define Up_trigF 2 // имя позиции триггер-флага кнопы Up_key в trig_flags
#define Ri_trigF 3 // имя позиции триггер-флага кнопы Right_key в trig_flags
#define Le_trigF 4 // имя позиции триггер-флага кнопы Left_key в trig_flags
//------------------------------------------------------------------------
// регистр флагов блокировки повторного исполнения до
// полного отпускания кнопки/комбинации кнопок
extern volatile byte trig_flags;
// указатель позиции массива технологических данных ("бегунок")
extern volatile byte window_ptr;
// флаг режима отображения 0 - работа текущего устройства
// 1 - режим отображения меню
extern volatile byte Fflag;
// флаг признака открытого окна настроек данных
// 0 - окна параметров закрыты
// 1 - окна параметров открыты
extern volatile byte FflagW;
// флаг "склерозника"
extern volatile byte skleroz;
// массив флагов разрешенных позиции для кнопок < и >
extern byte EnWindF[];
// массив технологческих данных
extern byte TehWind[];
// массив модулей максимального значения (модуля счета)
// в окне технологических данных
extern byte ModWind[];

//------------------------------------------------------------------------
// минимальная функция обработчика триггеров защиты
// от повторного выполнения задач
//"статус "все кнопки отпущены""
extern void OllOff();

// инициализация исходного состояния (блокировка)
// векторного селектора клавиатуры
extern void KeyStartInit();

// заполнение массива из 8 байт константой
extern void clr_mas(byte *, byte);

//.....................................................................
//     кнопка "<"
// перемещение курсора в виде децимальной точки влево по дисплею
extern void CurLeft();
//.....................................................................
//     кнопка ">"
// перемещение курсора в виде децимальной точки вправо по дисплею
extern void CurRight();

//.....................................................................
//     кнопка "вверх"
// инкремент значения в разрешенной (флаг в EnWindF[N]) позиции N
// массива технологических данных TehWind[N]
// модуль инкремента в ModWind[N]
extern void CurUp();
//.....................................................................
//     кнопка "вниз"
// инкремент значения в разрешенной (флаг в EnWindF[N]) позиции N
// массива технологических данных TehWind[N]
// модуль инкремента в ModWind[N]
extern void CurDn();

//.....................................................................
//     кнопка RK (Exec_key)
// в режиме работы текущего устройства
// обеспечивает переход в главное меню, при
// работе главного меню действует согласно селектора
// функций
extern void RK_key();

//.....................................................................
// общий участок инициализации перехода к главному меню
// от окна текущего работающего устройства
// аргумент - модуль количества субменюшек в устройстве
extern void masterMM(byte);

//------------------------------------------------------------------------
//           иные общие функции

//.....................................................................
// блок инициализации для режимов активации
// окон (меню/субменю)
extern void StartIniLabel();
//.....................................................................
// останов по критической ошибке
// аргументами ставим символы кода/номера ошибки
// вывод данных непосредствено в v_ram
extern void ErrorStop(byte, byte);
//.....................................................................
// запись одного байта в RAM RTC по заданному адресу
// адрес/данные
extern void wrbRamRtc(byte, byte);
//.....................................................................
// чтение одного байта в RAM RTC по заданному адресу
// аргумент адрес, возвращает байт данных
extern byte rdbRamRtc(byte);

//.....................................................................
//       обработчик актуаторов по подаче питания

// адрес ячейки энергонезависимой RAM RTC, выделенный под хранение
// индекса указателя на функцию-актуатор текущего устройства
#define AdrRtcFInd tmp_r50

// индекс указателя на функцию-актуатор текущего устройства
// (файла) при включении устройства
// (по уолчанию запуск индикации главных часов)
extern volatile byte StartFInd;

// селектор запуска устройств согласно индекса в StartFInd
extern void selFind();

// обработчик "холодного старта" - загрузки в RTC индекса на
// статус загрузки параметров из RTC для индикации отсчета
// главных часов
extern void ColdStart();



//------------------------------------------------------------------------

#endif      // Закрывающий #endif к блокировке повторного включения

//-------------конец файла/end of file---------------------
